<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => '1.0.0+no-version-set',
        'version' => '1.0.0.0',
        'reference' => null,
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => '1.0.0+no-version-set',
            'version' => '1.0.0.0',
            'reference' => null,
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'karriere/pdf-merge' => array(
            'pretty_version' => 'v3.3.1',
            'version' => '3.3.1.0',
            'reference' => 'd524a9d261ea96b18bbbab685b5710a7a0fe3a6e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../karriere/pdf-merge',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phrity/comparison' => array(
            'pretty_version' => '1.4.0',
            'version' => '1.4.0.0',
            'reference' => 'aedd44d59db08de7d6c31812d1490c22aab35c92',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phrity/comparison',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phrity/http' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => '536e3e46e6220d171a59599ed1f4da9f6b6244fc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phrity/http',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phrity/net-stream' => array(
            'pretty_version' => '2.3.1',
            'version' => '2.3.1.0',
            'reference' => 'c621bb3108a5a02bba64df2e5f0cd7ada02665b5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phrity/net-stream',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phrity/net-uri' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'reference' => '08de4cf07e439c4708f572249659f09198ac99f0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phrity/net-uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phrity/util-errorhandler' => array(
            'pretty_version' => '1.2.1',
            'version' => '1.2.1.0',
            'reference' => '9825f15ef9b4a93252ce53ca8962278832d834da',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phrity/util-errorhandler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phrity/websocket' => array(
            'pretty_version' => '3.6.0',
            'version' => '3.6.0.0',
            'reference' => '3f16b2564a230bbce716cccaff2f6156a60a8798',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phrity/websocket',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message' => array(
            'pretty_version' => '2.0',
            'version' => '2.0.0.0',
            'reference' => '402d35bcb92c70c026d1a6a9883f06b2ead23d71',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'f16e1d5863e37f8d8c2a01719f5b34baa2b714d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'tecnickcom/tcpdf' => array(
            'pretty_version' => '6.10.0',
            'version' => '6.10.0.0',
            'reference' => 'ca5b6de294512145db96bcbc94e61696599c391d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../tecnickcom/tcpdf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
